@@ -4,7 +4,7 @@ from .settings import *
 ROOT_URLCONF = 'tests.test_lemon_admin.urls'
 
 INSTALLED_APPS = (
-    'lemon.extradmin',
+    'lemon',
 ) + INSTALLED_APPS + (
     'tests.test_lemon_admin',
 )
