@@ -1,9 +1,8 @@
+import lemon
+
 from django.contrib import admin as django_admin
 from django.test import TestCase
 
-from lemon import extradmin as lemon_admin
-from lemon.extradmin import ModelAdmin
-
 from robots.admin import FileAdmin
 from robots.models import File
 
@@ -11,7 +10,7 @@ from robots.models import File
 class FileAdminTests(TestCase):
 
     def test_class(self):
-        self.assertFalse(issubclass(FileAdmin, ModelAdmin))
+        self.assertFalse(issubclass(FileAdmin, lemon.ModelAdmin))
 
 
 class AdminSiteTests(TestCase):
@@ -20,4 +19,4 @@ class AdminSiteTests(TestCase):
         self.assertIsInstance(django_admin.site._registry[File], FileAdmin)
 
     def test_file_isnt_registered_in_lemon(self):
-        self.assertNotIn(File, lemon_admin.site._registry)
+        self.assertNotIn(File, lemon.site._registry)
