@@ -1,13 +1,11 @@
-from django.conf import settings
 from django.contrib.sites.models import Site
 from django.test import TestCase, RequestFactory
 
 from robots.models import File
-from robots.utils import get_site_id
 from robots.views import robots_txt
 
 
-class RobotsTestCase(TestCase):
+class RobotsTxtViewTests(TestCase):
 
     def setUp(self):
         self.site1 = Site.objects.get(id=1)
@@ -24,21 +22,6 @@ class RobotsTestCase(TestCase):
             request.site = site
         return request
 
-
-class GetSiteIdTests(RobotsTestCase):
-
-    def test_uses_request_site_attr(self):
-        for site in (self.site1, self.site2):
-            site_id = get_site_id(self.get_request(site))
-            self.assertEqual(site_id, site.id)
-
-    def test_uses_site_from_settings(self):
-        site_id = get_site_id(self.get_request())
-        self.assertEqual(site_id, settings.SITE_ID)
-
-
-class RobotsTxtViewTests(RobotsTestCase):
-
     def test_has_file_object_in_context_if_exists(self):
         response = robots_txt(self.get_request(self.site1))
         self.assertEqual(response.context_data['object'], self.file)
